# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sessions_fields.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15sessions_fields.proto\x12\x1c\x61rmonik.api.grpc.v1.sessions\"S\n\x0fSessionRawField\x12@\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sessions.SessionRawEnumField\"S\n\x0fTaskOptionField\x12@\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sessions.TaskOptionEnumField\"\'\n\x16TaskOptionGenericField\x12\r\n\x05\x66ield\x18\x01 \x01(\t\"\x8a\x02\n\x0cSessionField\x12J\n\x11session_raw_field\x18\x01 \x01(\x0b\x32-.armonik.api.grpc.v1.sessions.SessionRawFieldH\x00\x12J\n\x11task_option_field\x18\x02 \x01(\x0b\x32-.armonik.api.grpc.v1.sessions.TaskOptionFieldH\x00\x12Y\n\x19task_option_generic_field\x18\x03 \x01(\x0b\x32\x34.armonik.api.grpc.v1.sessions.TaskOptionGenericFieldH\x00\x42\x07\n\x05\x66ield*\xca\x02\n\x13SessionRawEnumField\x12&\n\"SESSION_RAW_ENUM_FIELD_UNSPECIFIED\x10\x00\x12%\n!SESSION_RAW_ENUM_FIELD_SESSION_ID\x10\x01\x12!\n\x1dSESSION_RAW_ENUM_FIELD_STATUS\x10\x02\x12(\n$SESSION_RAW_ENUM_FIELD_PARTITION_IDS\x10\x03\x12\"\n\x1eSESSION_RAW_ENUM_FIELD_OPTIONS\x10\x04\x12%\n!SESSION_RAW_ENUM_FIELD_CREATED_AT\x10\x05\x12\'\n#SESSION_RAW_ENUM_FIELD_CANCELLED_AT\x10\x06\x12#\n\x1fSESSION_RAW_ENUM_FIELD_DURATION\x10\x07*\xc3\x03\n\x13TaskOptionEnumField\x12&\n\"TASK_OPTION_ENUM_FIELD_UNSPECIFIED\x10\x00\x12\'\n#TASK_OPTION_ENUM_FIELD_MAX_DURATION\x10\x01\x12&\n\"TASK_OPTION_ENUM_FIELD_MAX_RETRIES\x10\x02\x12#\n\x1fTASK_OPTION_ENUM_FIELD_PRIORITY\x10\x03\x12\'\n#TASK_OPTION_ENUM_FIELD_PARTITION_ID\x10\x04\x12+\n\'TASK_OPTION_ENUM_FIELD_APPLICATION_NAME\x10\x05\x12.\n*TASK_OPTION_ENUM_FIELD_APPLICATION_VERSION\x10\x06\x12\x30\n,TASK_OPTION_ENUM_FIELD_APPLICATION_NAMESPACE\x10\x07\x12.\n*TASK_OPTION_ENUM_FIELD_APPLICATION_SERVICE\x10\x08\x12&\n\"TASK_OPTION_ENUM_FIELD_ENGINE_TYPE\x10\tB\x1f\xaa\x02\x1c\x41rmoniK.Api.gRPC.V1.Sessionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sessions_fields_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\034ArmoniK.Api.gRPC.V1.Sessions'
  _globals['_SESSIONRAWENUMFIELD']._serialized_start=536
  _globals['_SESSIONRAWENUMFIELD']._serialized_end=866
  _globals['_TASKOPTIONENUMFIELD']._serialized_start=869
  _globals['_TASKOPTIONENUMFIELD']._serialized_end=1320
  _globals['_SESSIONRAWFIELD']._serialized_start=55
  _globals['_SESSIONRAWFIELD']._serialized_end=138
  _globals['_TASKOPTIONFIELD']._serialized_start=140
  _globals['_TASKOPTIONFIELD']._serialized_end=223
  _globals['_TASKOPTIONGENERICFIELD']._serialized_start=225
  _globals['_TASKOPTIONGENERICFIELD']._serialized_end=264
  _globals['_SESSIONFIELD']._serialized_start=267
  _globals['_SESSIONFIELD']._serialized_end=533
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sessions_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import sessions_common_pb2 as sessions__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16sessions_service.proto\x12\x1c\x61rmonik.api.grpc.v1.sessions\x1a\x15sessions_common.proto2\xf0\x02\n\x08Sessions\x12u\n\x0cListSessions\x12\x31.armonik.api.grpc.v1.sessions.ListSessionsRequest\x1a\x32.armonik.api.grpc.v1.sessions.ListSessionsResponse\x12q\n\nGetSession\x12/.armonik.api.grpc.v1.sessions.GetSessionRequest\x1a\x30.armonik.api.grpc.v1.sessions.GetSessionResponse\"\x00\x12z\n\rCancelSession\x12\x32.armonik.api.grpc.v1.sessions.CancelSessionRequest\x1a\x33.armonik.api.grpc.v1.sessions.CancelSessionResponse\"\x00\x42\x1f\xaa\x02\x1c\x41rmoniK.Api.gRPC.V1.Sessionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sessions_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\034ArmoniK.Api.gRPC.V1.Sessions'
  _globals['_SESSIONS']._serialized_start=80
  _globals['_SESSIONS']._serialized_end=448
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: results_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import result_status_pb2 as result__status__pb2
from . import results_fields_pb2 as results__fields__pb2
from . import results_filters_pb2 as results__filters__pb2
from . import sort_direction_pb2 as sort__direction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14results_common.proto\x12\x1b\x61rmonik.api.grpc.v1.results\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13result_status.proto\x1a\x14results_fields.proto\x1a\x15results_filters.proto\x1a\x14sort_direction.proto\"\xfa\x01\n\tResultRaw\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rowner_task_id\x18\x03 \x01(\t\x12?\n\x06status\x18\x04 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63ompleted_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tresult_id\x18\x08 \x01(\t\"\xb8\x02\n\x12ListResultsRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x35\n\x07\x66ilters\x18\x03 \x01(\x0b\x32$.armonik.api.grpc.v1.results.Filters\x12\x42\n\x04sort\x18\x04 \x01(\x0b\x32\x34.armonik.api.grpc.v1.results.ListResultsRequest.Sort\x1a\x85\x01\n\x04Sort\x12\x37\n\x05\x66ield\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.results.ResultField\x12\x44\n\tdirection\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sort_direction.SortDirection\"~\n\x13ListResultsResponse\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.results.ResultRaw\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"%\n\x10GetResultRequest\x12\x11\n\tresult_id\x18\x01 \x01(\t\"K\n\x11GetResultResponse\x12\x36\n\x06result\x18\x01 \x01(\x0b\x32&.armonik.api.grpc.v1.results.ResultRaw\">\n\x15GetOwnerTaskIdRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x03(\t\"\xb9\x01\n\x16GetOwnerTaskIdResponse\x12V\n\x0bresult_task\x18\x01 \x03(\x0b\x32\x41.armonik.api.grpc.v1.results.GetOwnerTaskIdResponse.MapResultTask\x12\x12\n\nsession_id\x18\x02 \x01(\t\x1a\x33\n\rMapResultTask\x12\x11\n\tresult_id\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\t\"\xa9\x01\n\x1c\x43reateResultsMetaDataRequest\x12W\n\x07results\x18\x01 \x03(\x0b\x32\x46.armonik.api.grpc.v1.results.CreateResultsMetaDataRequest.ResultCreate\x12\x12\n\nsession_id\x18\x02 \x01(\t\x1a\x1c\n\x0cResultCreate\x12\x0c\n\x04name\x18\x01 \x01(\t\"X\n\x1d\x43reateResultsMetaDataResponse\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.results.ResultRaw\"\xa7\x01\n\x14\x43reateResultsRequest\x12O\n\x07results\x18\x01 \x03(\x0b\x32>.armonik.api.grpc.v1.results.CreateResultsRequest.ResultCreate\x12\x12\n\nsession_id\x18\x02 \x01(\t\x1a*\n\x0cResultCreate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"P\n\x15\x43reateResultsResponse\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.results.ResultRaw\"\xc7\x01\n\x17UploadResultDataRequest\x12S\n\x02id\x18\x01 \x01(\x0b\x32\x45.armonik.api.grpc.v1.results.UploadResultDataRequest.ResultIdentifierH\x00\x12\x14\n\ndata_chunk\x18\x02 \x01(\x0cH\x00\x1a\x39\n\x10ResultIdentifier\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x01(\tB\x06\n\x04type\"R\n\x18UploadResultDataResponse\x12\x36\n\x06result\x18\x01 \x01(\x0b\x32&.armonik.api.grpc.v1.results.ResultRaw\"B\n#ResultsServiceConfigurationResponse\x12\x1b\n\x13\x64\x61ta_chunk_max_size\x18\x01 \x01(\x05\"B\n\x19\x44ownloadResultDataRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x01(\t\"0\n\x1a\x44ownloadResultDataResponse\x12\x12\n\ndata_chunk\x18\x01 \x01(\x0c\"A\n\x18\x44\x65leteResultsDataRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x03(\t\"B\n\x19\x44\x65leteResultsDataResponse\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x03(\tB\x1e\xaa\x02\x1b\x41rmoniK.Api.gRPC.V1.Resultsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'results_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\033ArmoniK.Api.gRPC.V1.Results'
  _globals['_RESULTRAW']._serialized_start=175
  _globals['_RESULTRAW']._serialized_end=425
  _globals['_LISTRESULTSREQUEST']._serialized_start=428
  _globals['_LISTRESULTSREQUEST']._serialized_end=740
  _globals['_LISTRESULTSREQUEST_SORT']._serialized_start=607
  _globals['_LISTRESULTSREQUEST_SORT']._serialized_end=740
  _globals['_LISTRESULTSRESPONSE']._serialized_start=742
  _globals['_LISTRESULTSRESPONSE']._serialized_end=868
  _globals['_GETRESULTREQUEST']._serialized_start=870
  _globals['_GETRESULTREQUEST']._serialized_end=907
  _globals['_GETRESULTRESPONSE']._serialized_start=909
  _globals['_GETRESULTRESPONSE']._serialized_end=984
  _globals['_GETOWNERTASKIDREQUEST']._serialized_start=986
  _globals['_GETOWNERTASKIDREQUEST']._serialized_end=1048
  _globals['_GETOWNERTASKIDRESPONSE']._serialized_start=1051
  _globals['_GETOWNERTASKIDRESPONSE']._serialized_end=1236
  _globals['_GETOWNERTASKIDRESPONSE_MAPRESULTTASK']._serialized_start=1185
  _globals['_GETOWNERTASKIDRESPONSE_MAPRESULTTASK']._serialized_end=1236
  _globals['_CREATERESULTSMETADATAREQUEST']._serialized_start=1239
  _globals['_CREATERESULTSMETADATAREQUEST']._serialized_end=1408
  _globals['_CREATERESULTSMETADATAREQUEST_RESULTCREATE']._serialized_start=1380
  _globals['_CREATERESULTSMETADATAREQUEST_RESULTCREATE']._serialized_end=1408
  _globals['_CREATERESULTSMETADATARESPONSE']._serialized_start=1410
  _globals['_CREATERESULTSMETADATARESPONSE']._serialized_end=1498
  _globals['_CREATERESULTSREQUEST']._serialized_start=1501
  _globals['_CREATERESULTSREQUEST']._serialized_end=1668
  _globals['_CREATERESULTSREQUEST_RESULTCREATE']._serialized_start=1626
  _globals['_CREATERESULTSREQUEST_RESULTCREATE']._serialized_end=1668
  _globals['_CREATERESULTSRESPONSE']._serialized_start=1670
  _globals['_CREATERESULTSRESPONSE']._serialized_end=1750
  _globals['_UPLOADRESULTDATAREQUEST']._serialized_start=1753
  _globals['_UPLOADRESULTDATAREQUEST']._serialized_end=1952
  _globals['_UPLOADRESULTDATAREQUEST_RESULTIDENTIFIER']._serialized_start=1887
  _globals['_UPLOADRESULTDATAREQUEST_RESULTIDENTIFIER']._serialized_end=1944
  _globals['_UPLOADRESULTDATARESPONSE']._serialized_start=1954
  _globals['_UPLOADRESULTDATARESPONSE']._serialized_end=2036
  _globals['_RESULTSSERVICECONFIGURATIONRESPONSE']._serialized_start=2038
  _globals['_RESULTSSERVICECONFIGURATIONRESPONSE']._serialized_end=2104
  _globals['_DOWNLOADRESULTDATAREQUEST']._serialized_start=2106
  _globals['_DOWNLOADRESULTDATAREQUEST']._serialized_end=2172
  _globals['_DOWNLOADRESULTDATARESPONSE']._serialized_start=2174
  _globals['_DOWNLOADRESULTDATARESPONSE']._serialized_end=2222
  _globals['_DELETERESULTSDATAREQUEST']._serialized_start=2224
  _globals['_DELETERESULTSDATAREQUEST']._serialized_end=2289
  _globals['_DELETERESULTSDATARESPONSE']._serialized_start=2291
  _globals['_DELETERESULTSDATARESPONSE']._serialized_end=2357
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: result_status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13result_status.proto\x12!armonik.api.grpc.v1.result_status*\x9c\x01\n\x0cResultStatus\x12\x1d\n\x19RESULT_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15RESULT_STATUS_CREATED\x10\x01\x12\x1b\n\x17RESULT_STATUS_COMPLETED\x10\x02\x12\x19\n\x15RESULT_STATUS_ABORTED\x10\x03\x12\x1a\n\x16RESULT_STATUS_NOTFOUND\x10\x7f\x42\x16\xaa\x02\x13\x41rmoniK.Api.gRPC.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'result_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\023ArmoniK.Api.gRPC.V1'
  _globals['_RESULTSTATUS']._serialized_start=59
  _globals['_RESULTSTATUS']._serialized_end=215
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FilterStringOperator(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    FILTER_STRING_OPERATOR_EQUAL: _ClassVar[FilterStringOperator]
    FILTER_STRING_OPERATOR_NOT_EQUAL: _ClassVar[FilterStringOperator]
    FILTER_STRING_OPERATOR_CONTAINS: _ClassVar[FilterStringOperator]
    FILTER_STRING_OPERATOR_NOT_CONTAINS: _ClassVar[FilterStringOperator]
    FILTER_STRING_OPERATOR_STARTS_WITH: _ClassVar[FilterStringOperator]
    FILTER_STRING_OPERATOR_ENDS_WITH: _ClassVar[FilterStringOperator]

class FilterNumberOperator(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    FILTER_NUMBER_OPERATOR_EQUAL: _ClassVar[FilterNumberOperator]
    FILTER_NUMBER_OPERATOR_NOT_EQUAL: _ClassVar[FilterNumberOperator]
    FILTER_NUMBER_OPERATOR_LESS_THAN: _ClassVar[FilterNumberOperator]
    FILTER_NUMBER_OPERATOR_LESS_THAN_OR_EQUAL: _ClassVar[FilterNumberOperator]
    FILTER_NUMBER_OPERATOR_GREATER_THAN_OR_EQUAL: _ClassVar[FilterNumberOperator]
    FILTER_NUMBER_OPERATOR_GREATER_THAN: _ClassVar[FilterNumberOperator]

class FilterDateOperator(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    FILTER_DATE_OPERATOR_EQUAL: _ClassVar[FilterDateOperator]
    FILTER_DATE_OPERATOR_NOT_EQUAL: _ClassVar[FilterDateOperator]
    FILTER_DATE_OPERATOR_BEFORE: _ClassVar[FilterDateOperator]
    FILTER_DATE_OPERATOR_BEFORE_OR_EQUAL: _ClassVar[FilterDateOperator]
    FILTER_DATE_OPERATOR_AFTER_OR_EQUAL: _ClassVar[FilterDateOperator]
    FILTER_DATE_OPERATOR_AFTER: _ClassVar[FilterDateOperator]

class FilterArrayOperator(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    FILTER_ARRAY_OPERATOR_CONTAINS: _ClassVar[FilterArrayOperator]
    FILTER_ARRAY_OPERATOR_NOT_CONTAINS: _ClassVar[FilterArrayOperator]

class FilterStatusOperator(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    FILTER_STATUS_OPERATOR_EQUAL: _ClassVar[FilterStatusOperator]
    FILTER_STATUS_OPERATOR_NOT_EQUAL: _ClassVar[FilterStatusOperator]

class FilterBooleanOperator(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    FILTER_BOOLEAN_OPERATOR_IS: _ClassVar[FilterBooleanOperator]
FILTER_STRING_OPERATOR_EQUAL: FilterStringOperator
FILTER_STRING_OPERATOR_NOT_EQUAL: FilterStringOperator
FILTER_STRING_OPERATOR_CONTAINS: FilterStringOperator
FILTER_STRING_OPERATOR_NOT_CONTAINS: FilterStringOperator
FILTER_STRING_OPERATOR_STARTS_WITH: FilterStringOperator
FILTER_STRING_OPERATOR_ENDS_WITH: FilterStringOperator
FILTER_NUMBER_OPERATOR_EQUAL: FilterNumberOperator
FILTER_NUMBER_OPERATOR_NOT_EQUAL: FilterNumberOperator
FILTER_NUMBER_OPERATOR_LESS_THAN: FilterNumberOperator
FILTER_NUMBER_OPERATOR_LESS_THAN_OR_EQUAL: FilterNumberOperator
FILTER_NUMBER_OPERATOR_GREATER_THAN_OR_EQUAL: FilterNumberOperator
FILTER_NUMBER_OPERATOR_GREATER_THAN: FilterNumberOperator
FILTER_DATE_OPERATOR_EQUAL: FilterDateOperator
FILTER_DATE_OPERATOR_NOT_EQUAL: FilterDateOperator
FILTER_DATE_OPERATOR_BEFORE: FilterDateOperator
FILTER_DATE_OPERATOR_BEFORE_OR_EQUAL: FilterDateOperator
FILTER_DATE_OPERATOR_AFTER_OR_EQUAL: FilterDateOperator
FILTER_DATE_OPERATOR_AFTER: FilterDateOperator
FILTER_ARRAY_OPERATOR_CONTAINS: FilterArrayOperator
FILTER_ARRAY_OPERATOR_NOT_CONTAINS: FilterArrayOperator
FILTER_STATUS_OPERATOR_EQUAL: FilterStatusOperator
FILTER_STATUS_OPERATOR_NOT_EQUAL: FilterStatusOperator
FILTER_BOOLEAN_OPERATOR_IS: FilterBooleanOperator

class FilterString(_message.Message):
    __slots__ = ["value", "operator"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    OPERATOR_FIELD_NUMBER: _ClassVar[int]
    value: str
    operator: FilterStringOperator
    def __init__(self, value: _Optional[str] = ..., operator: _Optional[_Union[FilterStringOperator, str]] = ...) -> None: ...

class FilterNumber(_message.Message):
    __slots__ = ["value", "operator"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    OPERATOR_FIELD_NUMBER: _ClassVar[int]
    value: int
    operator: FilterNumberOperator
    def __init__(self, value: _Optional[int] = ..., operator: _Optional[_Union[FilterNumberOperator, str]] = ...) -> None: ...

class FilterDate(_message.Message):
    __slots__ = ["value", "operator"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    OPERATOR_FIELD_NUMBER: _ClassVar[int]
    value: _timestamp_pb2.Timestamp
    operator: FilterDateOperator
    def __init__(self, value: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., operator: _Optional[_Union[FilterDateOperator, str]] = ...) -> None: ...

class FilterArray(_message.Message):
    __slots__ = ["value", "operator"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    OPERATOR_FIELD_NUMBER: _ClassVar[int]
    value: str
    operator: FilterArrayOperator
    def __init__(self, value: _Optional[str] = ..., operator: _Optional[_Union[FilterArrayOperator, str]] = ...) -> None: ...

class FilterBoolean(_message.Message):
    __slots__ = ["value", "operator"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    OPERATOR_FIELD_NUMBER: _ClassVar[int]
    value: bool
    operator: FilterBooleanOperator
    def __init__(self, value: bool = ..., operator: _Optional[_Union[FilterBooleanOperator, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: filters_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x66ilters_common.proto\x12\x13\x61rmonik.api.grpc.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"Z\n\x0c\x46ilterString\x12\r\n\x05value\x18\x01 \x01(\t\x12;\n\x08operator\x18\x02 \x01(\x0e\x32).armonik.api.grpc.v1.FilterStringOperator\"Z\n\x0c\x46ilterNumber\x12\r\n\x05value\x18\x01 \x01(\x03\x12;\n\x08operator\x18\x02 \x01(\x0e\x32).armonik.api.grpc.v1.FilterNumberOperator\"r\n\nFilterDate\x12)\n\x05value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x08operator\x18\x02 \x01(\x0e\x32\'.armonik.api.grpc.v1.FilterDateOperator\"X\n\x0b\x46ilterArray\x12\r\n\x05value\x18\x01 \x01(\t\x12:\n\x08operator\x18\x02 \x01(\x0e\x32(.armonik.api.grpc.v1.FilterArrayOperator\"\\\n\rFilterBoolean\x12\r\n\x05value\x18\x01 \x01(\x08\x12<\n\x08operator\x18\x02 \x01(\x0e\x32*.armonik.api.grpc.v1.FilterBooleanOperator*\xfa\x01\n\x14\x46ilterStringOperator\x12 \n\x1c\x46ILTER_STRING_OPERATOR_EQUAL\x10\x00\x12$\n FILTER_STRING_OPERATOR_NOT_EQUAL\x10\x01\x12#\n\x1f\x46ILTER_STRING_OPERATOR_CONTAINS\x10\x02\x12\'\n#FILTER_STRING_OPERATOR_NOT_CONTAINS\x10\x03\x12&\n\"FILTER_STRING_OPERATOR_STARTS_WITH\x10\x04\x12$\n FILTER_STRING_OPERATOR_ENDS_WITH\x10\x05*\x8e\x02\n\x14\x46ilterNumberOperator\x12 \n\x1c\x46ILTER_NUMBER_OPERATOR_EQUAL\x10\x00\x12$\n FILTER_NUMBER_OPERATOR_NOT_EQUAL\x10\x01\x12$\n FILTER_NUMBER_OPERATOR_LESS_THAN\x10\x02\x12-\n)FILTER_NUMBER_OPERATOR_LESS_THAN_OR_EQUAL\x10\x03\x12\x30\n,FILTER_NUMBER_OPERATOR_GREATER_THAN_OR_EQUAL\x10\x04\x12\'\n#FILTER_NUMBER_OPERATOR_GREATER_THAN\x10\x05*\xec\x01\n\x12\x46ilterDateOperator\x12\x1e\n\x1a\x46ILTER_DATE_OPERATOR_EQUAL\x10\x00\x12\"\n\x1e\x46ILTER_DATE_OPERATOR_NOT_EQUAL\x10\x01\x12\x1f\n\x1b\x46ILTER_DATE_OPERATOR_BEFORE\x10\x02\x12(\n$FILTER_DATE_OPERATOR_BEFORE_OR_EQUAL\x10\x03\x12\'\n#FILTER_DATE_OPERATOR_AFTER_OR_EQUAL\x10\x04\x12\x1e\n\x1a\x46ILTER_DATE_OPERATOR_AFTER\x10\x05*a\n\x13\x46ilterArrayOperator\x12\"\n\x1e\x46ILTER_ARRAY_OPERATOR_CONTAINS\x10\x00\x12&\n\"FILTER_ARRAY_OPERATOR_NOT_CONTAINS\x10\x01*^\n\x14\x46ilterStatusOperator\x12 \n\x1c\x46ILTER_STATUS_OPERATOR_EQUAL\x10\x00\x12$\n FILTER_STATUS_OPERATOR_NOT_EQUAL\x10\x01*7\n\x15\x46ilterBooleanOperator\x12\x1e\n\x1a\x46ILTER_BOOLEAN_OPERATOR_IS\x10\x00\x42\x16\xaa\x02\x13\x41rmonik.Api.gRPC.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'filters_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\023Armonik.Api.gRPC.V1'
  _globals['_FILTERSTRINGOPERATOR']._serialized_start=563
  _globals['_FILTERSTRINGOPERATOR']._serialized_end=813
  _globals['_FILTERNUMBEROPERATOR']._serialized_start=816
  _globals['_FILTERNUMBEROPERATOR']._serialized_end=1086
  _globals['_FILTERDATEOPERATOR']._serialized_start=1089
  _globals['_FILTERDATEOPERATOR']._serialized_end=1325
  _globals['_FILTERARRAYOPERATOR']._serialized_start=1327
  _globals['_FILTERARRAYOPERATOR']._serialized_end=1424
  _globals['_FILTERSTATUSOPERATOR']._serialized_start=1426
  _globals['_FILTERSTATUSOPERATOR']._serialized_end=1520
  _globals['_FILTERBOOLEANOPERATOR']._serialized_start=1522
  _globals['_FILTERBOOLEANOPERATOR']._serialized_end=1577
  _globals['_FILTERSTRING']._serialized_start=78
  _globals['_FILTERSTRING']._serialized_end=168
  _globals['_FILTERNUMBER']._serialized_start=170
  _globals['_FILTERNUMBER']._serialized_end=260
  _globals['_FILTERDATE']._serialized_start=262
  _globals['_FILTERDATE']._serialized_end=376
  _globals['_FILTERARRAY']._serialized_start=378
  _globals['_FILTERARRAY']._serialized_end=466
  _globals['_FILTERBOOLEAN']._serialized_start=468
  _globals['_FILTERBOOLEAN']._serialized_end=560
# @@protoc_insertion_point(module_scope)



from . import objects_pb2 as _objects_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProcessRequest(_message.Message):
    __slots__ = ["communication_token", "compute"]
    class ComputeRequest(_message.Message):
        __slots__ = ["init_request", "payload", "init_data", "data"]
        class InitRequest(_message.Message):
            __slots__ = ["configuration", "session_id", "task_id", "task_options", "expected_output_keys", "payload"]
            CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
            SESSION_ID_FIELD_NUMBER: _ClassVar[int]
            TASK_ID_FIELD_NUMBER: _ClassVar[int]
            TASK_OPTIONS_FIELD_NUMBER: _ClassVar[int]
            EXPECTED_OUTPUT_KEYS_FIELD_NUMBER: _ClassVar[int]
            PAYLOAD_FIELD_NUMBER: _ClassVar[int]
            configuration: _objects_pb2.Configuration
            session_id: str
            task_id: str
            task_options: _objects_pb2.TaskOptions
            expected_output_keys: _containers.RepeatedScalarFieldContainer[str]
            payload: _objects_pb2.DataChunk
            def __init__(self, configuration: _Optional[_Union[_objects_pb2.Configuration, _Mapping]] = ..., session_id: _Optional[str] = ..., task_id: _Optional[str] = ..., task_options: _Optional[_Union[_objects_pb2.TaskOptions, _Mapping]] = ..., expected_output_keys: _Optional[_Iterable[str]] = ..., payload: _Optional[_Union[_objects_pb2.DataChunk, _Mapping]] = ...) -> None: ...
        class InitData(_message.Message):
            __slots__ = ["key", "last_data"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            LAST_DATA_FIELD_NUMBER: _ClassVar[int]
            key: str
            last_data: bool
            def __init__(self, key: _Optional[str] = ..., last_data: bool = ...) -> None: ...
        INIT_REQUEST_FIELD_NUMBER: _ClassVar[int]
        PAYLOAD_FIELD_NUMBER: _ClassVar[int]
        INIT_DATA_FIELD_NUMBER: _ClassVar[int]
        DATA_FIELD_NUMBER: _ClassVar[int]
        init_request: ProcessRequest.ComputeRequest.InitRequest
        payload: _objects_pb2.DataChunk
        init_data: ProcessRequest.ComputeRequest.InitData
        data: _objects_pb2.DataChunk
        def __init__(self, init_request: _Optional[_Union[ProcessRequest.ComputeRequest.InitRequest, _Mapping]] = ..., payload: _Optional[_Union[_objects_pb2.DataChunk, _Mapping]] = ..., init_data: _Optional[_Union[ProcessRequest.ComputeRequest.InitData, _Mapping]] = ..., data: _Optional[_Union[_objects_pb2.DataChunk, _Mapping]] = ...) -> None: ...
    COMMUNICATION_TOKEN_FIELD_NUMBER: _ClassVar[int]
    COMPUTE_FIELD_NUMBER: _ClassVar[int]
    communication_token: str
    compute: ProcessRequest.ComputeRequest
    def __init__(self, communication_token: _Optional[str] = ..., compute: _Optional[_Union[ProcessRequest.ComputeRequest, _Mapping]] = ...) -> None: ...

class ProcessReply(_message.Message):
    __slots__ = ["communication_token", "output"]
    COMMUNICATION_TOKEN_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    communication_token: str
    output: _objects_pb2.Output
    def __init__(self, communication_token: _Optional[str] = ..., output: _Optional[_Union[_objects_pb2.Output, _Mapping]] = ...) -> None: ...

class HealthCheckReply(_message.Message):
    __slots__ = ["status"]
    class ServingStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNKNOWN: _ClassVar[HealthCheckReply.ServingStatus]
        SERVING: _ClassVar[HealthCheckReply.ServingStatus]
        NOT_SERVING: _ClassVar[HealthCheckReply.ServingStatus]
    UNKNOWN: HealthCheckReply.ServingStatus
    SERVING: HealthCheckReply.ServingStatus
    NOT_SERVING: HealthCheckReply.ServingStatus
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: HealthCheckReply.ServingStatus
    def __init__(self, status: _Optional[_Union[HealthCheckReply.ServingStatus, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tasks_filters.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import filters_common_pb2 as filters__common__pb2
from . import task_status_pb2 as task__status__pb2
from . import tasks_fields_pb2 as tasks__fields__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13tasks_filters.proto\x12\x19\x61rmonik.api.grpc.v1.tasks\x1a\x14\x66ilters_common.proto\x1a\x11task_status.proto\x1a\x12tasks_fields.proto\"\x87\x01\n\x0c\x46ilterStatus\x12:\n\x05value\x18\x01 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12;\n\x08operator\x18\x02 \x01(\x0e\x32).armonik.api.grpc.v1.FilterStatusOperator\"\xbf\x03\n\x0b\x46ilterField\x12\x33\n\x05\x66ield\x18\x01 \x01(\x0b\x32$.armonik.api.grpc.v1.tasks.TaskField\x12:\n\rfilter_string\x18\x02 \x01(\x0b\x32!.armonik.api.grpc.v1.FilterStringH\x00\x12:\n\rfilter_number\x18\x03 \x01(\x0b\x32!.armonik.api.grpc.v1.FilterNumberH\x00\x12<\n\x0e\x66ilter_boolean\x18\x04 \x01(\x0b\x32\".armonik.api.grpc.v1.FilterBooleanH\x00\x12@\n\rfilter_status\x18\x05 \x01(\x0b\x32\'.armonik.api.grpc.v1.tasks.FilterStatusH\x00\x12\x36\n\x0b\x66ilter_date\x18\x06 \x01(\x0b\x32\x1f.armonik.api.grpc.v1.FilterDateH\x00\x12\x38\n\x0c\x66ilter_array\x18\x07 \x01(\x0b\x32 .armonik.api.grpc.v1.FilterArrayH\x00\x42\x11\n\x0fvalue_condition\"A\n\nFiltersAnd\x12\x33\n\x03\x61nd\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.tasks.FilterField\"<\n\x07\x46ilters\x12\x31\n\x02or\x18\x01 \x03(\x0b\x32%.armonik.api.grpc.v1.tasks.FiltersAndB\x1c\xaa\x02\x19\x41rmonik.Api.gRPC.V1.Tasksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tasks_filters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\031Armonik.Api.gRPC.V1.Tasks'
  _globals['_FILTERSTATUS']._serialized_start=112
  _globals['_FILTERSTATUS']._serialized_end=247
  _globals['_FILTERFIELD']._serialized_start=250
  _globals['_FILTERFIELD']._serialized_end=697
  _globals['_FILTERSAND']._serialized_start=699
  _globals['_FILTERSAND']._serialized_end=764
  _globals['_FILTERS']._serialized_start=766
  _globals['_FILTERS']._serialized_end=826
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class TaskStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    TASK_STATUS_UNSPECIFIED: _ClassVar[TaskStatus]
    TASK_STATUS_CREATING: _ClassVar[TaskStatus]
    TASK_STATUS_SUBMITTED: _ClassVar[TaskStatus]
    TASK_STATUS_DISPATCHED: _ClassVar[TaskStatus]
    TASK_STATUS_COMPLETED: _ClassVar[TaskStatus]
    TASK_STATUS_ERROR: _ClassVar[TaskStatus]
    TASK_STATUS_TIMEOUT: _ClassVar[TaskStatus]
    TASK_STATUS_CANCELLING: _ClassVar[TaskStatus]
    TASK_STATUS_CANCELLED: _ClassVar[TaskStatus]
    TASK_STATUS_PROCESSING: _ClassVar[TaskStatus]
    TASK_STATUS_PROCESSED: _ClassVar[TaskStatus]
    TASK_STATUS_RETRIED: _ClassVar[TaskStatus]
TASK_STATUS_UNSPECIFIED: TaskStatus
TASK_STATUS_CREATING: TaskStatus
TASK_STATUS_SUBMITTED: TaskStatus
TASK_STATUS_DISPATCHED: TaskStatus
TASK_STATUS_COMPLETED: TaskStatus
TASK_STATUS_ERROR: TaskStatus
TASK_STATUS_TIMEOUT: TaskStatus
TASK_STATUS_CANCELLING: TaskStatus
TASK_STATUS_CANCELLED: TaskStatus
TASK_STATUS_PROCESSING: TaskStatus
TASK_STATUS_PROCESSED: TaskStatus
TASK_STATUS_RETRIED: TaskStatus



import enum

from ..protogen.common.task_status_pb2 import *
from ..protogen.common.worker_common_pb2 import HealthCheckReply

# This file is necessary because the grpc types aren't considered proper types


class HealthCheckStatus(enum.Enum):
    NOT_SERVING = HealthCheckReply.NOT_SERVING
    SERVING = HealthCheckReply.SERVING
    UNKNOWN = HealthCheckReply.UNKNOWN


class TaskStatus(enum.Enum):
    CANCELLED = TASK_STATUS_CANCELLED
    CANCELLING = TASK_STATUS_CANCELLING
    COMPLETED = TASK_STATUS_COMPLETED
    CREATING = TASK_STATUS_CREATING
    DISPATCHED = TASK_STATUS_DISPATCHED
    ERROR = TASK_STATUS_ERROR
    PROCESSED = TASK_STATUS_PROCESSED
    PROCESSING = TASK_STATUS_PROCESSING
    SUBMITTED = TASK_STATUS_SUBMITTED
    TIMEOUT = TASK_STATUS_TIMEOUT
    UNSPECIFIED = TASK_STATUS_UNSPECIFIED
